#ifdef GL_ES
varying lowp vec4 v_fragmentColor;
varying mediump vec2 v_texCoord;
#else
varying vec4 v_fragmentColor;
varying vec2 v_texCoord;
#endif

//RGB to HSV
vec3 RGBConvertToHSV(vec3 rgb)
{
    float K = 0.0;
    if (rgb.g < rgb.b)
    {
        float tmp = rgb.g; rgb.g = rgb.b; rgb.b = tmp;
        K = -1.0;
    }
    if (rgb.r < rgb.g)
    {
        float tmp = rgb.r; rgb.r = rgb.g; rgb.g = tmp;
        K = -2.0 / 6.0 - K;
    }
    
    float chroma = rgb.r - (rgb.g < rgb.b ? rgb.g : rgb.b);
    return vec3(abs(K + (rgb.g - rgb.b) / (6.0 * chroma + 1e-20)), chroma / (rgb.r + 1e-20), rgb.r);
}

//HSV to RGB
vec3 HSVConvertToRGB(vec3 hsv)
{
    float R,G,B;
    if( hsv.y == 0.0)
    {
        R=G=B=hsv.z;
    }
    else
    {
        hsv.x = mod(hsv.x, 1.0) * 6.0;
        int i = int(hsv.x);
        float f = hsv.x - float(i);
        float a = hsv.z * ( 1.0 - hsv.y );
        float b = hsv.z * ( 1.0 - hsv.y * f );
        float c = hsv.z * ( 1.0 - hsv.y * (1.0 - f ) );
        if (i == 0)
        {
            R = hsv.z; G = c; B = a;
        }
        else if (i == 1)
        {
            R = b; G = hsv.z; B = a;
        }
        else if (i == 2)
        {
            R = a; G = hsv.z; B = c;
        }
        else if (i == 3)
        {
            R = a; G = b; B = hsv.z;
        }
        else if (i == 4)
        {
            R = c; G = a; B = hsv.z;
        }
        else
        {
            R = hsv.z; G = a; B = b;
        }
    }
    return vec3(R,G,B);
}

void main()
{
    vec4 original = texture2D(CC_Texture0, v_texCoord);
    if (original.a == 0.0)
    {
        discard;
    }
    vec3 colorHSV = RGBConvertToHSV(original.rgb);
    colorHSV.r += v_fragmentColor.r;

    original.rgb = HSVConvertToRGB(colorHSV);
    
    gl_FragColor = original;
}
